@@ -1,4 +1,5 @@
-from typing import List, Tuple
+from typing import List
+from typing import Tuple
 
 import pandas as pd
 
@@ -8,10 +9,16 @@ from sqltest.datasource.reader import DatasetReader
 class ExcelDatasetReader(DatasetReader):
     def __init__(self, data_path: str, engine="openpyxl"):
         self._data_file = pd.ExcelFile(data_path, engine=engine)
-        self.source_sheets = [source for source in self._data_file.sheet_names if
-                              source.startswith('source--')]
-        self.target_sheets = [source for source in self._data_file.sheet_names if
-                              source.startswith('target--')]
+        self.source_sheets = [
+            source
+            for source in self._data_file.sheet_names
+            if source.startswith("source--")
+        ]
+        self.target_sheets = [
+            source
+            for source in self._data_file.sheet_names
+            if source.startswith("target--")
+        ]
 
     def read_source_data(self) -> List[Tuple[str, pd.DataFrame]]:
         for sheet in self.source_sheets:
